# Runtime for Program Generated by Mirage's Transpiler

Files in this directory are runtime files for CUDA programs generated by Mirage's transpiler. They are NOT intended to be included by the Mirage project itself.
